
# q-expansion of newform 8024.2.a.w, downloaded from the LMFDB on 12 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 8024
weight = 2
poly_data = [4, 18, -193, -427, 2473, 3386, -10680, -9059, 18269, 11260, -15668, -7342, 7532, 2629, -2114, -514, 341, 51, -29, -2, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-3, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-2838889908921188, -19375772586548854, 77862311219996419, 284652088557900286, -439383939498289035, -975831262333912997, 832500114255853691, 1390326752397642422, -757325016683489087, -1003553197024123219, 382733090508826625, 398068393698951039, -113035793829052437, -88763268731180322, 19138039203739608, 10857857034782738, -1693927234801715, -662031832725318, 60125553049071, 15008099526873], 324854300335192], [[1211960300269868, 2541759662072204, -21080340326808055, -47892053345017289, 73537393675682740, 193148281561856521, -82227210328563488, -307028737628062186, 24089902119823135, 246389210490892014, 14094405788903625, -111301235840544898, -11590228934722691, 29480854261259565, 3086727461685201, -4513408121091215, -361220750544340, 366647734887630, 15707606525101, -12145529660002], 162427150167596], [[992821189787352, 2060400142794990, -36097994348251449, -41788977255725345, 216042989594827158, 96373519748605197, -457770153580060112, -65348280333808960, 476230862128798891, -10812584908264084, -273283568562233103, 33678474302062024, 89562392021593723, -16797496500552161, -16454188961202605, 3770351597264549, 1558574906472928, -398443278955476, -58870048375111, 16020819195294], 162427150167596], [[-8688382894365628, -26389126429491226, 194498856062150625, 475471083274295272, -890798728393047619, -1819299238556713483, 1399019659984449431, 2802119763452223462, -1002870192289540545, -2174981033621691055, 363131113987540267, 939297843063741795, -65991058903842495, -234425038995395728, 4892237529723266, 33419691122965832, 56976029903065, -2510754831620630, -17936170631519, 76645812152769], 649708600670384], [[-1373594821745228, -7871426233683754, 23863906306901029, 135097212817084372, 50044312233059173, -557561862694552919, -672256097331311529, 1041146529330288966, 1278742982669404531, -1032687384505394863, -1023878782469119281, 587750038012930235, 412850241478513821, -195327724726328228, -86824555481956378, 36596855043647524, 9009384589595321, -3518580791424854, -362894116240403, 133807711367713], 649708600670384], [[-219488687815120, 926188356680900, 20729954385889876, -66401913895826783, -193714951616106737, 474359037002118578, 463145176045539225, -920844546752854704, -511492737522328872, 815185399315337013, 302875427718787716, -387930886724892339, -100594395526169050, 105230105835551111, 18600077304590315, -16202416085915791, -1775850676626261, 1310195314921200, 67952978646472, -42993313897265], 162427150167596], [[-1318382064499428, -7266793329230786, 33438588650521935, 142773250581423458, -105896011211267101, -606765074011869397, 48018581620782459, 1010287773076944792, 113991057443289155, -841687619283022289, -143049604633506475, 391495676868724363, 66498123155735181, -106012809629079580, -14923641765964600, 16496086110920408, 1610169485420061, -1356148938261212, -66818051107591, 45331988284303], 162427150167596], [[-1533584563137276, 20728924604707286, 81599324284293657, -372178521461350052, -769321476487400719, 1959071038543433605, 1952850981557902643, -3564532060563709578, -2271774499757568745, 3111824616481401453, 1402612592468224371, -1492102673133149905, -481851404628608415, 413017817795868572, 91424611791938302, -65349816905214356, -8885338469872435, 5444741689527450, 343669186525913, -184101995107787], 649708600670384], [[-435029148696828, 6169267865881726, 46572047820776361, -202750840008521224, -477978667829286251, 1110591771138454285, 1264141963182752687, -2039264779030142170, -1518770889869864953, 1804039893884647513, 963571764254885067, -882469490014203597, -338645504851607879, 250563594140693376, 65395288982125354, -40760274008323080, -6434602754611047, 3488891386882426, 250843014352425, -120925478470383], 324854300335192], [[5087224973914476, 38672885783596418, -89126045129340541, -852273689684712872, 63860054656180327, 3927555504213749439, 576773204913683829, -6657626202798049406, -1230247495177683859, 5527004308621554643, 994281512735783585, -2533427590015832951, -395779143570416637, 670799251315472128, 82161373952496470, -101591826901346296, -8485562766894213, 8117295406965246, 343389161409139, -263860853334045], 649708600670384], [[1127675225727556, 11555573337297482, 23651666818882825, -234667880139975948, -423467513867776255, 1228023278495875625, 1316521826657137191, -2272630270692215286, -1732814191116594453, 2045658820045451989, 1162725972686421455, -1021744885212321625, -423436485953518199, 296597362424934872, 83656310171524474, -49280507797760916, -8352082277543607, 4297621691911310, 328605339348677, -151331030049999], 324854300335192], [[292932332005348, -3551592323591632, -17976868945581973, 105786552896986378, 216446665902964519, -541340773534791955, -700125008525691579, 1006134369947103434, 955721189306466233, -925368179657787681, -657051372951100069, 477161979795830635, 243289363599210233, -143674251387053078, -48603045690399934, 24737934398925096, 4885900865202215, -2225832307186190, -192949961716001, 80461065143945], 162427150167596], [[-5804452142803164, -50663249088470778, 122692605606049573, 935900795295101504, -156624587821843463, -4130225627329007871, -741110452971478765, 6965910068684820806, 1761207932731377075, -5842039110756528915, -1474980530814644993, 2734315745423201031, 599534902485367861, -745542319166916016, -126079224026400470, 116856652484531984, 13102163715311677, -9676518745643606, -530619240509251, 325730164389989], 649708600670384], [[1046948189106380, 36440601667275146, 40764924466738319, -680181069548745356, -756407891702026433, 3217787591851186899, 2514828501259415125, -5701979413137081982, -3444621996449845175, 4995360138329745683, 2362942329726706325, -2440377683595008103, -870857250127774401, 694218163273023404, 173221349864172914, -113259303600444996, -17370734467795253, 9722347482910126, 685783496165623, -337802121038101], 649708600670384], [[1690249535830228, 42412043842306222, 11534034404218717, -899269310777046384, -605186153912782583, 4339754271391070289, 2069702343217216147, -7552293932285297114, -2833982038707421957, 6404249699245177357, 1933483257300435759, -2999329290824778145, -707467471865722875, 812769418774309376, 139910079550614274, -126108343143376008, -13994753185826803, 10321456573893306, 552989699504901, -343398705436307], 649708600670384], [[-6028723425803332, -42553984246960834, 114190401142210877, 765517191406150336, -175910025104156383, -3273486924765045663, -507756287116343477, 5460871544306186342, 1323862194602930747, -4560792386051901571, -1129872805579749937, 2130966451539884599, 462576009374162421, -580606292069891768, -97618304344007118, 90977414723089360, 10164264475770781, -7532771991506694, -412127320209451, 253562826274429], 324854300335192], [[-1598584945561284, -57941447455183990, -19970081243144425, 1149168002702691532, 873392466186698711, -5395630552419661493, -3364025157563174907, 9481058514763719002, 4934592548073371881, -8242987434195879221, -3516988101925865587, 4000786456942655977, 1326893469526979935, -1132310976476300436, -267961414877285062, 184038309862958588, 27147611165227707, -15754972942733434, -1079538820370601, 546278944556307], 649708600670384]]

hecke_ring_character_values = None
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1, 0, 1, 0, 0, 0, -1, 0, 0, 0, 0, 0, -1, 0], [1, 0, 0, 0, -1, 0, -1, -1, 0, 0, 0, 1, -1, 0, 1, -1, 0, -1, 0, 0], [-2, 0, -1, 0, -1, 1, 0, -1, 1, -1, -1, 0, 0, 1, 0, -1, 1, 0, 1, 1], [0, 1, 0, -1, -1, 1, 0, -1, 0, 0, 1, 0, 1, 0, 0, -1, 0, -2, 1, -1], [0, 0, 0, 0, -1, -1, 0, 1, -1, -1, 0, 1, 0, 0, -1, -1, 0, 0, 1, 0], [-1, -1, 1, 0, 0, 0, -2, 0, 1, -1, 0, 0, -1, -1, 0, -1, 1, -1, 1, 0], [1, 0, 0, 0, 1, 0, 0, 1, 0, 0, -1, -1, -1, -1, 0, 1, 0, 0, -1, -1], [-1, -1, 0, 0, 1, -1, 0, 2, 0, 0, -1, -2, -1, 1, -2, 1, -1, 3, -1, 1], [0, -1, 0, 0, 1, -1, -1, 1, 0, 0, 1, -1, -1, 0, 0, 1, -2, 0, -1, 0], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 3, -1, 3, 0, 0, 2, -2, -1, 2, 0, -1, 2, -1, 2, 0, -1, 0, -2, 0], [1, 3, -1, 0, -1, 0, 0, -1, -1, -1, 0, 1, 1, 1, 1, -1, -2, 1, 0, -1], [1, 2, 0, 1, 0, 0, 0, 0, -2, 0, 0, 1, 2, 0, 0, -1, -1, -1, 0, -1], [-4, 2, 0, 1, 1, 0, 1, -2, 1, 1, 0, 1, 2, 0, 0, -2, 2, -2, 1, 0], [0, 2, 1, 0, 1, -2, -1, 1, -1, 0, 1, 1, 0, -1, -1, -2, 0, 0, 1, 0], [-3, 3, 0, 0, 1, 0, -1, 1, -1, 2, 0, -1, 2, 1, -1, 1, 1, -1, 2, 0], [-2, -1, -1, -1, 0, 0, -1, 2, 1, 0, -2, 1, -2, 1, -1, 1, -1, 2, 0, 1], [-5, -2, 0, 0, 1, 2, 0, -2, 2, 1, 0, -1, 0, -1, 1, 2, -1, -1, -1, 0], [-1, 2, 0, 3, 5, -1, 2, 0, -1, 2, 0, -1, 1, -2, 1, 1, 1, 1, -3, -1], [-3, 3, 0, 1, 1, 0, 2, 0, 1, 0, 0, 0, 2, 0, 0, -3, 1, 1, 1, 1], [1, 4, -2, 2, 0, 0, 3, 0, -2, 3, 1, -1, 3, -2, 2, 1, -2, -2, -4, 0], [-3, -6, 1, 0, 2, 2, 1, 1, 2, -1, -1, 0, -3, -1, 0, 3, 3, 0, 0, -1], [-1, 4, -2, -1, -3, -1, 1, 3, -3, 0, 3, -1, 3, 0, 0, 2, -4, -4, -1, -2], [-3, -5, 2, 0, 1, 2, -2, -1, 4, 0, 0, 0, -1, -1, 1, -1, 5, -1, 0, 2], [-1, -1, 2, -2, 1, 1, -4, -2, 3, 0, 0, 3, -1, 1, 0, -2, 6, -2, 4, 1], [-1, -7, 1, -3, -1, 2, 0, -1, 3, -1, -1, 0, 0, -2, 1, 3, 4, -4, -2, -1], [-2, 0, 0, -2, 1, -1, 0, 0, -1, 0, 2, 0, 1, -2, 2, 1, 1, -3, 2, -2], [0, 4, 0, 1, 0, 0, 1, 0, -1, 4, 4, 0, 2, -2, 2, 2, -3, -4, -4, -4], [-4, 0, -1, 3, 1, -1, 3, 1, 0, 0, -1, -2, 0, -2, -1, -1, -2, 5, -4, 4], [-1, 0, 1, 1, 1, 1, -1, 1, -2, -1, 0, 1, 0, 3, -1, -2, 1, 0, 4, 0], [2, 0, 1, 1, 0, 0, 1, 2, -3, -1, 0, 0, -1, 0, 2, 1, -1, 3, 0, -1], [-2, 1, 0, -1, 1, 1, 2, 0, 0, -1, -1, 1, -2, 0, -1, -2, 3, -1, 2, 0], [-3, -8, 2, 0, 2, 3, 1, -2, 4, 0, -3, -2, -2, -1, -1, 6, 1, 3, -2, 0], [-1, 2, -1, 2, 2, -1, 3, 3, -2, 0, 0, -2, 0, -2, -2, 3, -4, 4, -2, 0], [-2, -2, 2, -1, 1, 1, 0, 1, 1, 1, -2, -1, 1, -1, 1, 3, 3, -2, -1, -1], [2, -1, -2, -1, 0, -1, 2, 3, -4, -2, 3, 1, 0, 1, 1, -1, 1, -2, 1, -2], [-3, 1, 1, 0, 0, 0, -1, -2, 2, 1, 1, 4, 1, -2, 1, -5, 6, -5, 2, -1], [-3, 3, -1, -1, -1, 0, -2, 3, -5, -2, 1, -1, 2, 6, -3, -2, 0, 2, 8, 2], [-2, 6, -2, 1, -2, -2, 2, -1, -2, -1, 3, -1, 6, 0, -1, -3, -2, 1, 1, 1], [2, 2, 0, 1, -5, 1, -1, -3, 0, -2, 1, 3, -2, 2, 1, -3, -2, 1, 1, 1], [-4, -8, 4, -5, 2, 4, -4, -3, 7, -2, -4, 1, -2, 0, -2, 2, 7, -3, 6, -1], [-4, 0, 2, 2, 0, -1, -1, 0, 1, 0, 1, 0, 3, 2, -1, -1, 0, 0, 3, 3], [3, 6, 0, 1, -4, -2, 0, -3, -1, 1, 3, 3, 3, -1, 0, -5, -2, -4, -1, 0], [-5, -2, 3, -2, 0, 1, -3, -4, 5, 1, -1, 1, -1, -2, -1, 2, 2, -4, 1, -4], [2, 2, 0, 0, 0, 0, -2, 3, -2, -1, 0, 0, 1, 2, 0, 3, -3, 3, 0, -2], [-7, -1, -1, 2, 0, -1, 3, 0, -2, 1, 0, -2, 1, 3, -2, -2, 0, 6, 1, 4], [-2, -4, -1, -3, -2, 0, 1, -1, 1, -4, -2, 0, 0, 2, -2, -4, 3, 2, 4, 5], [-7, 7, -3, 1, -1, 1, 3, -3, -3, -2, 3, 2, 3, 2, 1, -7, 3, -3, 2, 1], [-3, 0, 2, 3, 0, -1, 1, 2, 1, 3, 3, -2, 2, -2, 1, 1, -3, -3, -3, -2], [-1, 0, 1, 2, -3, -1, -2, -1, -2, 2, 1, -2, 2, 1, 0, 2, -2, 0, 0, 2], [-4, -3, -2, 0, 2, 2, 2, 0, 0, 2, -1, -3, 1, 2, 0, 5, 0, 6, 0, 0], [-4, -5, 3, -2, -2, 1, -2, 2, 2, -3, -3, 2, -4, 2, -1, -1, 3, 3, 3, 3], [-3, -5, -1, 0, 2, 2, 0, -3, 1, 1, -1, 1, -1, -1, 2, 3, 2, -1, -2, 1], [2, -1, 1, 1, -2, 3, -6, -3, 1, 0, 1, 3, -2, 2, 0, -3, 2, 1, 2, 1], [-4, -5, 1, -1, 0, 3, 2, -4, 7, 4, -1, -1, -2, -4, 2, 4, -2, -4, -6, -2], [-6, 3, 0, 4, -2, -2, 3, -1, 1, 1, -1, -2, 3, 0, -2, -1, 0, 4, -2, 3], [2, -6, 0, -5, -5, 1, -4, -1, 2, -4, -3, 2, -2, 4, -1, -4, 4, -1, 4, 4], [-3, 1, -3, 3, 2, -3, 5, 1, 0, 4, 0, -2, 0, -2, 2, 5, -6, 6, -8, -2], [-2, -1, 0, 0, -1, -1, -3, 3, -3, -5, 1, 1, -2, 5, -1, -1, -3, 4, 5, 3], [4, -3, 2, 2, 3, 1, 0, 0, 2, 3, -4, 1, -2, -2, 1, 3, -2, 2, -5, -1], [-3, 4, 3, 1, 1, -2, -5, 1, -2, 0, -1, 1, -1, 2, -2, -4, -1, 4, 5, 2], [1, -2, 5, -1, 3, -1, 0, 1, 2, 1, -3, 0, -1, -5, 1, 5, 3, 2, -1, -2], [0, -4, 2, -4, 1, 1, -3, 0, 3, 0, -4, 5, -4, -3, 1, 1, 8, -3, 2, 1], [-2, -4, 2, -1, 3, 2, 0, -1, 3, 1, 0, 3, -4, -6, 4, 1, 3, 2, -4, -3], [-2, -4, 0, -4, -4, -1, -4, 0, -1, -4, 1, 0, -1, 6, -4, -5, 1, -1, 7, 6], [-1, 3, -2, 1, -1, -1, 2, 5, -2, 2, 0, -3, 0, 3, -4, 3, -6, 6, -3, 1], [1, -4, -2, -3, -1, 1, 3, 1, -1, 0, 4, 2, -1, -3, 0, 3, -4, -4, -2, -6], [1, -5, 0, -3, -1, 0, -3, 2, 3, -1, -3, -1, -2, 4, -2, 2, 3, 0, 4, 1], [2, -3, -2, -1, 1, 2, 3, 2, 1, -1, -5, -6, -1, 5, -2, 6, -6, 6, 0, -1], [-6, -2, 4, -1, 2, 0, 2, 5, 3, 0, -1, -1, -1, -5, -3, 3, 0, -1, -3, -3], [-2, 1, 1, 1, -5, -3, -2, 0, 1, -1, -1, -1, -2, 1, -1, -4, 0, 3, -4, 4], [2, -8, 3, -4, -1, -1, -6, 1, 3, -7, -6, 1, -6, 5, -3, -4, 4, 9, 7, 4], [-3, -4, 1, 0, 2, -2, -1, 6, -2, -3, 1, -3, -5, 3, -3, 0, -3, 6, 3, 2], [-6, 2, 2, 2, 3, -2, 4, 1, 1, 6, 4, -3, 2, -9, 0, 7, -7, -1, -10, -2], [-2, -7, 4, -2, -4, 1, -6, 2, 5, -1, -1, -1, -5, 4, -3, -3, -2, -1, 0, 2], [-1, -4, -2, 0, 3, 3, 5, -1, 0, 1, -2, -2, 0, -1, 2, 6, 1, -1, -2, -5], [-8, -4, 1, -1, 4, -2, 2, 6, -2, 0, 0, -3, 0, -4, -4, 3, -1, 1, -2, -1], [-5, 1, 0, 0, 9, 2, 5, 3, -3, 5, 2, -2, 4, -6, 2, 9, -2, -5, -4, -10], [-3, 3, 0, -2, 3, 3, 4, 6, -3, 0, 2, -1, 1, 0, -4, 7, -4, -1, 2, -5], [2, 11, -9, 4, -4, 0, 11, 1, -9, 1, 7, -5, 12, 4, 3, 0, -9, -1, -1, -3], [2, 10, -6, 3, -2, 0, 9, 0, -10, 1, 7, -2, 8, 3, 5, -1, -7, 1, -3, -2], [2, 7, 3, 3, -3, 0, -7, -7, 0, 1, 1, 6, -1, -1, 2, -9, 4, -5, 1, 2], [2, 4, -2, 7, 6, -4, 0, 5, -5, 5, 3, 1, 1, -3, 3, -2, -2, 4, -3, 2], [9, 2, 4, 0, -2, 1, -8, -7, 3, -2, -3, 8, -2, 2, 1, -6, 5, -3, 5, -1], [1, -4, 4, 0, 1, -2, -4, -2, 2, -1, -1, 2, -4, -3, 0, -4, 3, 0, 1, 0], [-1, -1, 1, -2, -3, 2, 3, -2, 0, 1, -2, -4, 1, -1, 2, 5, -3, 0, -1, -5], [2, -1, 2, -4, -3, 2, 1, -8, 4, -1, 1, 0, 2, 0, 0, -5, 4, -8, 1, -1], [2, -4, 2, -4, -2, 1, -6, -2, 0, -3, -1, 7, -1, 3, 0, -5, 7, -2, 9, 2], [7, -4, 0, -3, -4, 7, -6, -5, 5, -5, -1, 6, -3, 5, 1, -10, 8, -2, 9, 3], [-2, -4, 0, -1, 5, 0, 0, -3, 3, 3, -1, 0, -1, -6, 6, 3, 8, -5, -3, -2], [-3, -1, 2, 1, 2, -2, 1, 0, -3, 2, -1, 0, 2, -5, 2, 5, -1, 2, -5, 0], [-5, 2, -2, 2, 2, -3, 0, 4, -2, 1, -1, -7, 1, 2, -5, 2, -8, 10, -2, 2], [-3, -12, 5, -5, 1, 2, -6, -3, 8, -3, -5, 2, -6, 2, -3, -3, 7, -1, 7, 4], [-6, 9, -3, 2, 1, -2, 4, 4, -4, 1, 5, -5, 4, -2, -2, -1, -10, -1, -3, -1], [-4, 17, 2, 7, 4, -2, 3, -3, -2, 7, 4, 1, 6, -4, 3, 0, -4, -2, -6, -7], [-6, -4, 2, -5, 5, 2, 5, 2, 2, 1, -1, 0, 0, -8, 0, 6, 7, -4, -2, -2], [0, -1, 2, 1, -4, -1, -3, -7, 3, 3, -1, -2, 0, 1, -1, 1, -3, -3, -2, 2], [-2, -16, 1, -3, 3, 1, -1, 6, 3, -4, -3, -3, -8, 1, -3, 1, 1, 9, -2, 6], [-7, 6, -6, 2, -3, -1, 3, 1, -5, 3, 1, -4, 0, 4, 1, 1, -7, 7, -2, 2], [6, 2, -1, 0, -6, -2, -5, -4, 5, -1, -3, 2, -2, 0, -3, -7, 0, -1, -1, 6], [1, 15, -8, 3, -9, -4, 6, 2, -8, 0, 5, 1, 8, 5, -3, -11, -8, 4, 0, 6], [7, 6, -3, 1, -4, -5, -1, 8, -5, 2, 1, -5, 1, 0, -1, 4, -14, 2, -4, 0], [-11, -3, -2, 1, 4, 0, -1, 6, -2, 1, -1, -5, -2, 0, -2, 7, -9, 7, -4, -1], [6, -9, 1, -1, -2, 0, -1, 0, 6, 1, -2, -2, -5, -5, 1, 2, -1, 3, -7, 1], [3, -5, 3, -2, -1, -4, -9, 3, 3, -1, 2, 3, -8, -2, -1, -6, 3, -4, 0, 3], [-9, -4, 5, 0, 6, 3, 0, -4, 1, -1, 2, 2, 1, -2, 4, -4, 8, -2, 5, -3], [-1, 2, -3, 3, -2, 1, 5, 0, -4, -3, 1, 1, 2, 7, -1, -7, 6, 2, 3, 5], [-4, 8, 0, 1, 2, 1, 2, 6, -10, -1, -1, 0, -1, 3, -2, 2, -4, 5, 6, -3], [-6, 1, -5, 3, -1, -2, 3, 8, -1, 2, 0, -1, -2, 2, -6, 4, -8, 7, -7, 2], [5, 5, -1, 3, -9, -9, -7, 0, -3, 3, 6, 0, 2, 2, 1, -4, -8, -6, -6, 5], [0, -18, 6, -2, 2, 2, -4, -2, 9, -4, -4, 1, -8, 4, -1, 1, 9, -1, 3, 4], [-3, 4, -4, -1, 2, -2, 7, 5, -6, 1, 3, -1, 1, 0, -2, 0, -5, 3, -1, -1], [4, 3, 1, -2, -2, -1, -5, 0, -1, -6, -7, 3, -3, 6, -3, -7, 5, 7, 8, 6], [6, 4, -2, 1, -3, 3, 4, -6, -2, -2, 6, 3, 9, 1, 4, -5, 1, -8, 4, -6], [-1, 3, -1, -2, -1, -1, 2, -3, 2, 1, 4, 0, 2, -3, 1, -2, -3, -2, -5, -2], [2, 10, -3, 8, 3, -4, 6, -1, -8, 3, 2, -1, 8, -5, 3, -5, -1, -2, -3, -1], [-1, -8, 3, 0, -1, 3, -2, -7, 5, -1, -5, -1, -3, 2, 2, -3, 8, -2, 3, 5], [-1, -10, 4, -3, -4, 5, -10, 0, 1, -3, -2, 0, -4, 11, -4, 2, 2, 2, 7, 3], [0, 2, -2, 2, 4, -1, 5, 5, -8, -2, 0, -5, 3, 0, 2, 1, -2, 5, 0, -1], [3, -6, 4, 0, 3, 7, -3, -3, 8, 0, -5, 5, -6, -3, 5, 0, 8, -5, 2, -3], [5, 15, -8, 9, 3, -2, 5, -3, -6, 12, 5, 0, 7, -7, 7, 4, -10, -3, -13, -7], [-5, -2, 1, 0, 2, 1, 4, -4, 3, 3, 0, 1, -3, -3, 3, 3, -1, -2, -5, -5], [-5, -9, 3, -6, 0, 0, -6, -5, 6, -4, -4, -5, -5, 2, -4, 6, -1, 5, 3, 4], [-4, 3, -4, 4, 6, -2, 6, 6, -3, 2, 0, -9, 1, 1, -2, 7, -12, 11, -9, -1], [5, -7, 1, -4, 1, 3, -2, 0, 3, -3, -4, 3, -6, -1, 1, -1, 10, 1, 3, 0], [-5, -7, -3, 2, 4, -1, 9, 0, 1, 6, -1, -2, 2, -9, 5, 14, -5, -1, -12, -6], [-3, 10, -5, -2, -4, -2, 5, 3, -8, 0, 0, -4, 3, 2, 0, 6, -5, 3, -1, 0], [-3, 6, -3, -1, -1, -5, 2, 3, -5, -1, 2, 1, 1, -2, -3, -3, -5, 5, -3, 1], [-7, 5, -2, 0, -2, -5, 3, 2, -4, 1, -1, -2, 6, -2, -2, -3, -4, 1, 3, 0], [-3, 5, -4, 4, 5, 0, -1, 1, 1, 2, -6, 1, -4, -1, 2, 1, 4, 3, -5, 1], [-1, -9, 1, -2, -4, 3, -3, -6, 5, -2, -4, 2, -7, 1, 1, 1, 3, 3, -4, 3], [4, 1, 1, -6, -4, -2, 0, 1, -3, -4, 1, 3, -2, 1, 0, -6, -2, 0, 6, 0], [-2, 0, 1, -4, 2, 1, -3, 0, -4, 0, 4, 2, 1, -4, 3, 7, 4, -4, 1, -7], [0, 0, -2, -2, -7, -1, -4, -2, 2, -6, 1, 0, 3, 5, -2, -6, -2, 2, 6, 7], [-2, 5, -5, 4, -7, -1, -1, 2, -7, -1, 7, -4, 5, 11, -6, -6, -9, 0, 8, 5], [-7, 3, 3, 2, 4, -1, -4, 1, -3, -1, 1, 1, -1, 1, -3, -2, 2, 2, 2, 0], [2, 5, -4, -4, 0, 2, 3, 0, -3, -1, 3, 6, 0, -2, 3, 3, 1, -10, -1, -6], [-11, 6, 5, 3, 7, -6, 1, 0, 0, 6, 4, -3, 5, -7, 0, 1, 0, -4, -5, -4], [4, -11, 6, -2, 2, 4, -4, -7, 10, -1, -10, 5, -8, 0, -1, -1, 12, -1, -1, 4], [5, -5, -3, 0, 1, -4, 3, 10, -8, 0, 4, -5, 4, -2, 2, 6, -9, 3, -8, -6], [-2, -4, 3, -1, 7, -3, -1, 0, 7, 2, -2, -1, -8, -7, -1, 5, 0, 6, -4, -5], [-1, -4, -4, -3, 0, -1, -5, 6, 3, -2, 2, -3, -3, 6, -5, 4, -4, 0, 3, 3], [-1, -2, 0, 7, 4, -1, 3, 4, 2, 3, -5, 1, -3, -1, 2, -1, 3, 9, -2, 7], [2, 9, 0, -4, -1, 5, -6, -6, 4, 1, 0, 5, 0, 5, 1, -3, 9, -8, 8, -5], [2, -8, 4, -7, -1, 2, 3, 5, -1, -2, 2, 0, 1, -1, -1, 6, 7, -7, 4, -4], [12, 10, -4, 3, -3, -3, 4, 5, -7, 5, 5, 2, 2, 0, 1, 0, -8, 2, -5, -6], [-3, -5, -1, 5, -1, 2, 3, 3, -1, -2, 1, -2, 4, 4, -4, -1, -2, 3, 0, 2], [-3, -15, 4, -2, 3, 3, -4, -3, 6, -1, -8, 2, -7, -3, -1, 5, 10, 4, 5, -1], [-9, -5, 5, 1, 0, -6, 4, 0, 9, 6, 0, -3, -1, -11, -2, -1, -2, -4, -12, 1], [3, 10, -5, 5, 2, -4, 3, 3, -7, 1, 1, -1, 4, 1, 1, 3, -6, 4, -4, 1], [-2, -4, 7, 0, -6, -1, -5, -5, 3, 0, 0, 4, -2, -1, 3, -2, 8, -7, 4, 4], [-5, 1, 1, -4, -5, 3, 3, -2, 3, -8, -6, 2, -2, 6, -1, -6, 9, 6, 6, 8], [-8, -2, 0, -1, -4, -1, -1, 0, 0, -1, 2, -2, 4, 0, -4, -1, -4, -1, 0, 5], [15, 12, -3, 9, 5, -7, 13, 3, -9, 6, 7, -5, 8, -8, 5, 5, -10, 6, -14, -4], [9, 6, -3, -6, -6, 2, -6, -2, -7, -9, -1, 11, -2, 12, 1, -10, 7, -3, 15, 1], [3, -8, 8, 4, 7, -4, -4, 5, 5, 2, -7, -5, -6, 0, -3, 4, -2, 10, -6, 4], [7, -3, 0, -7, -9, 3, -4, 0, 0, -10, 3, 6, -4, 7, -3, -8, 2, -4, 13, -1], [5, 15, -3, 7, -1, -2, 6, 3, -10, -3, 5, -2, 3, 2, 1, 0, -12, 3, -5, 0], [13, -24, 3, -7, 1, 2, -3, -1, 10, -3, -7, 2, -11, 0, -2, 9, 2, 5, -6, 2], [7, -2, 1, 3, -1, 5, -5, -8, 4, 3, 0, 9, -1, 0, 8, 0, 2, -1, 0, -8], [2, 12, -3, 5, 2, 1, -2, -1, -6, 6, 5, -2, 8, -1, 2, 4, -2, -7, -5, -4], [-11, 11, -7, 9, 8, -4, 10, 10, -9, 2, 2, -6, 4, -3, 3, 4, -8, 6, -8, -2], [0, 16, -6, 2, -7, -2, 9, 3, -4, 2, 7, -5, 11, 1, -4, -5, -12, -1, -6, 0], [11, -4, -4, -7, -3, 7, 1, -9, 2, -5, 2, 0, 1, 3, 7, -5, 7, -9, 7, -2], [4, 6, -6, 1, -5, 3, -2, -2, -4, 1, 4, 2, 6, 1, 1, -3, -2, -7, -1, 0], [-11, 4, 4, 6, 5, 1, 3, -4, 2, 8, -3, 2, 3, -5, 3, 0, 4, -4, -2, -4], [-9, -15, 2, -4, 4, 2, -3, 9, 1, -4, -8, -11, -6, 8, -8, 9, 0, 15, 3, 5], [-11, 9, -7, -4, -3, 0, 6, 2, -2, -2, -2, -3, 9, 2, -6, 0, -1, 1, 3, 2], [-2, 6, -4, -4, -2, -4, -1, 7, -8, -6, 5, 0, -3, -1, 1, 1, -3, -2, 2, -6], [2, -4, -4, -3, 1, -1, -1, 2, -1, -5, 2, 2, -10, 2, 0, -8, 9, -2, 4, 4], [16, -5, -2, -1, 2, -7, 1, 8, -6, -1, 3, -3, 4, -1, -4, 5, -6, 7, 3, 0], [-4, 12, -3, 5, -4, -5, 4, -1, -7, 0, 7, 0, 6, 1, 1, -8, -6, -1, 0, 9], [0, -14, 5, -10, 0, 6, -10, -3, 11, -4, -4, -2, -10, 5, -3, 6, 11, -5, 7, 2], [-3, -22, 6, -5, 5, 3, -1, 2, 8, -1, -3, -5, -9, -4, -2, 14, 1, 11, -1, 0], [-8, 2, -5, 3, 6, 0, 11, 4, -1, 4, 2, -2, 1, -8, 2, 0, 1, -1, -10, -4], [5, -4, 0, 1, -2, -4, -7, 2, 3, -2, -5, 1, -4, 6, -6, -8, 1, 10, 0, 8], [-4, -9, 6, -7, 5, 1, -6, 0, 7, 2, -7, -1, -7, -6, 2, 16, 6, -4, 0, -4], [11, 14, -6, 2, -2, 1, 4, -9, -6, 3, 7, 0, 12, 3, 7, -9, 1, -9, 3, -1], [5, -6, -6, 2, -4, -1, 1, 5, -4, -5, -6, -3, -3, 9, -1, 0, -6, 17, -2, 11], [-2, 2, 1, 0, -4, 0, 3, -1, 4, -3, -1, -2, 0, 2, -2, -5, 2, 5, 3, 11], [-4, 11, 0, 2, 1, -1, 4, -1, -6, 0, 1, 3, 2, -3, 4, -4, 6, -4, 4, -4], [-1, 4, -10, 6, -4, 0, 11, -1, -6, -4, -1, -5, 4, 2, 0, -4, -7, 9, -7, 6], [14, 0, 8, 1, -1, 1, -5, -6, 5, -1, -1, 0, 2, 1, -1, -3, 6, -1, 3, -2], [9, 3, -3, 2, 1, 4, 5, -2, -1, 1, -1, 0, 3, -6, 6, 6, 1, -4, -7, -12], [11, -2, 5, -5, 1, -3, -1, 1, 3, 1, -1, 0, -2, -7, -1, 5, -3, -7, -1, -3], [1, -13, 3, 2, -4, 7, 5, -9, 8, -2, -6, -3, -5, -1, 2, 5, 1, 5, -7, -1], [6, -3, -1, -5, -2, 5, -1, 4, 4, -2, -1, -2, 0, 4, -3, 13, -9, -7, 1, -7], [-2, 3, 1, 9, 10, 1, 6, -12, 4, 6, -1, 2, 7, -9, 7, -8, 10, -7, -3, -1], [-8, 1, 7, -2, -5, 0, -5, -4, 1, -1, 1, -3, 0, 1, -4, 2, -7, 3, 3, 0], [-8, 0, -5, 0, 4, 1, 1, 12, -5, -2, -6, -5, -4, 2, -2, 10, -6, 6, -1, 1], [0, -4, -2, 3, 2, 2, 1, -2, 3, -1, -8, -2, -11, 5, 2, 7, -5, 15, -6, 6], [-7, 7, 1, -3, 1, 2, -2, 0, 7, -5, 0, 3, -3, 1, -4, -6, 2, 2, 4, 1], [3, -8, -2, 1, -3, -7, 2, 7, -1, 0, -2, -2, 0, -3, -3, 1, -2, 2, -5, 0], [6, 15, -4, 8, 1, -1, 3, -5, -7, 2, 5, 6, -1, 4, 7, -3, -5, 8, 2, -4], [-4, 2, -5, 1, 5, -4, 1, 3, -1, 4, -2, -7, 5, -5, 4, 10, -2, -2, -6, 0], [-3, -2, 0, 2, 9, -2, 6, -2, 1, 2, -1, 6, 0, -12, 2, 1, 4, -4, -5, -2], [-2, 6, 7, -2, 1, 4, -8, -9, 6, 1, 1, 7, -5, -2, 6, -5, 11, -7, 6, -3], [4, 6, -1, 2, 3, -7, 3, -5, 1, 8, -2, 0, 2, -11, 7, 9, -5, -5, -13, 1], [-4, 12, -1, 5, 6, -2, 3, 8, -9, -1, 5, -1, -6, 3, -3, 3, -9, 14, 0, -4], [4, 11, -7, 1, -9, -4, 4, -7, -5, -1, 5, -2, 11, -1, 1, -9, -5, -2, -2, 4], [2, -1, 1, 0, -2, 0, 5, 2, -2, -6, -1, 1, 0, -8, 0, -7, 6, -7, 3, -3], [-5, 14, 0, 7, 6, 0, 7, 7, -8, 4, 1, -3, 12, -3, -5, 12, -5, 2, -2, -7], [-9, -1, 3, -4, 6, 7, 6, -2, 2, 1, 2, -3, 5, -4, 2, 7, -1, 0, 2, -10], [-2, -16, 3, -10, -4, 11, -3, -3, 7, -5, -7, 1, -11, 9, 0, 3, 13, -1, 10, 1], [4, -13, 2, -6, 4, 3, 2, -1, 2, -1, 4, 2, 1, -9, 7, 1, 9, -7, -1, -6], [-7, -6, -5, 3, 3, -6, 12, -1, 2, -1, 0, 0, 4, -10, 4, 1, 1, 3, -14, 1], [12, -5, 1, 2, -3, 4, 0, 7, 0, -3, -3, 0, -5, 2, -5, 0, -6, 6, -3, -1], [2, -3, 3, -10, -3, 3, -11, 3, 0, -6, -2, 4, -8, 8, -3, -4, 1, -2, 12, 0], [-7, 11, -3, -1, 3, -6, -2, 1, -2, 0, 1, 1, 9, 0, -3, -6, 0, -3, 8, 1], [4, -11, 4, 2, 0, -1, -2, 1, 3, 0, -5, -1, -10, -3, 5, 4, -6, 13, -9, 3], [7, 3, 1, -1, 2, 4, -3, -4, -1, -4, -1, 3, -8, 8, 1, -10, 7, 3, 5, 6], [11, 29, -9, 8, 2, -3, 11, 3, -20, -3, 8, 5, 12, 3, 5, -10, -8, -2, 2, -5], [10, -4, -9, 0, -7, 2, 9, -1, -2, 4, 3, -4, -1, -1, 2, 7, -11, -1, -13, -3], [10, -16, 5, -9, 0, 3, -13, -1, 4, 0, -2, 9, -7, 3, -2, -1, 10, -12, 6, -2], [6, -6, -1, -7, -8, -4, -11, -6, 5, 0, 2, 10, -7, 0, 5, 0, 3, -16, -3, 0], [14, 1, 4, -4, -4, 6, -8, -5, 4, -4, -4, 7, -8, 3, 2, -6, 3, 4, 4, 2], [11, 9, -8, 5, 3, 0, 7, 4, -14, -2, 1, 0, 0, 3, 5, -2, -5, 13, 0, -1], [7, -2, -1, -6, 3, -4, -3, 1, -1, 1, 1, 2, 0, -4, 4, -1, 2, 5, 2, -6], [-12, -18, 3, -9, -1, 6, 0, 2, 10, -6, -2, -6, -1, 1, -4, 2, 17, -11, 8, 2], [-5, -8, -1, -1, 4, 1, 2, -9, 7, 0, -6, 0, -2, -3, 0, -7, 3, 3, 0, -2], [10, -6, -5, -2, -9, 2, 0, -8, 3, -4, 3, 4, 0, 5, 1, -6, 1, -2, -1, 3], [-8, 22, -7, 8, 4, -7, 11, 0, -9, 8, 6, -6, 20, -6, -1, 0, -9, 2, -7, -3], [8, 3, -1, -1, -14, -3, 7, 1, -8, -2, 7, -4, 11, 6, -6, 0, -16, 0, 1, 0], [9, 9, -4, -7, -7, -2, -8, 4, 1, -5, -1, -1, -4, 8, -11, -2, -5, 7, 7, 6], [0, -4, -4, -2, -4, 1, -2, -1, -1, 1, -2, 2, 2, -3, 4, 5, 0, -8, -1, -5], [-5, 3, -9, -3, 1, 0, 12, 4, -4, 1, 5, -11, 11, -5, -1, 9, -7, -7, -5, -5], [-5, -5, 11, -1, -1, 1, -9, 0, 8, 4, -1, -5, 3, 1, -3, 1, 4, -8, -1, 6], [4, 3, 0, -1, 2, 3, 8, -7, 2, 6, -2, 2, 2, -4, 7, 5, 3, -9, 0, -6], [0, 4, 2, 7, 3, -1, 0, 3, 2, 7, 4, -6, 1, 3, -5, 5, -10, 3, -7, -3], [-10, 2, 7, 2, 12, 1, 0, 1, 8, 10, -4, 0, -3, -9, 4, 9, 7, 3, -7, -8], [0, -10, -2, -5, 0, -3, -3, 3, 5, 1, -1, -3, -1, 0, -6, 3, 1, -2, 2, 2], [6, -11, 1, -10, -4, 4, -11, 3, 7, -2, -4, -1, -6, 6, -7, -3, 8, -12, 11, 0], [-1, 2, -5, -1, 4, 2, 6, -8, 7, 3, 6, 0, -6, -8, 6, -9, 3, -10, -5, -2], [11, -2, -5, 0, 0, 8, 15, -10, 4, -6, -4, 3, 3, -2, 4, -4, 8, 4, 0, 2], [2, 3, -2, -10, -8, 0, -9, -5, -1, -4, 7, 4, 7, 5, 3, -9, 6, -19, 10, -5], [3, 8, -3, 7, 5, -3, 3, 4, -8, 13, 7, -3, 4, -5, 6, 4, -8, -3, -15, -2], [-10, -15, 4, -3, 4, 7, 2, 1, 11, 1, -4, -3, -12, -3, -2, 10, 3, -2, -5, 1], [-16, -4, 7, 1, 10, 0, 3, -3, 14, 13, -1, -8, -1, -10, 5, 8, 3, -4, -12, 1], [13, 12, -1, 2, 9, -4, 0, -1, 3, 3, -3, 5, -3, -9, 3, 2, -2, 8, -6, -7], [7, -2, -5, -2, -16, 3, 1, -6, 3, -11, 3, 4, 0, 9, 0, -16, 7, -4, 7, 8], [0, -29, 6, -13, -2, 9, -12, 0, 14, -6, -9, 2, -12, 8, -6, 2, 15, 4, 8, 10], [2, -35, 3, -8, 0, 5, -3, 1, 11, -12, -12, -3, -17, 5, -5, 9, 2, 22, -2, 10], [2, 9, -4, 5, -7, -3, -4, 3, -4, 0, -3, -1, 1, 10, -1, -7, -5, 13, -2, 13], [2, -7, 16, -11, 4, -2, -11, 4, 11, -3, -2, 1, -4, 2, -12, -4, 10, -4, 16, 4], [-13, 2, -1, 6, 6, 0, 1, 1, -4, 7, 5, -4, 4, 2, -1, 9, -2, 4, 1, -5], [5, 5, 2, 4, 4, -11, 5, 8, -10, 3, 5, -4, 1, -6, -3, -1, -5, 7, -4, 3], [-11, -3, -3, -3, 3, -5, 7, 3, 0, -1, 0, -9, -3, -2, -6, 7, -9, 5, -3, -2], [4, 27, -6, -5, 1, -2, -1, -1, -7, -1, 10, 1, 14, -6, 5, -8, 3, -15, 6, -5], [-10, 4, -2, -1, -3, 1, 6, 3, -2, -4, 6, -3, 3, 6, -3, -8, 2, -1, 11, 7], [1, 7, -1, -7, -18, -3, -6, -5, -1, -2, 0, 8, 7, 5, 2, -11, 1, -12, 10, 1], [-1, 6, 3, -2, -2, 2, -4, -6, -3, -5, 4, -3, 6, 4, -2, -4, -1, 0, 12, 2], [-16, 6, -7, 6, 4, 1, 7, 7, -8, 0, -4, -6, 4, 4, -4, 8, -5, 12, 1, 1], [-1, -13, 2, -13, -4, 3, 4, 6, 1, -5, 1, -3, -2, 3, -5, 7, -2, -7, 5, -3], [3, -11, 0, -7, -4, -1, -10, 8, 4, -7, 2, -2, -3, -2, -4, 2, -2, -2, 3, -2], [3, 0, 1, 4, 3, 1, 2, -4, 1, 9, 6, -8, 4, -1, 1, 7, -7, 3, -1, 3], [18, -2, -5, 1, -7, -2, -3, 0, -2, -4, 5, 8, -4, 0, 6, -9, -2, -8, -2, -4], [8, 14, -6, 1, 0, -6, -1, 11, -10, -3, 4, -1, 5, 9, -2, -2, -11, 4, 4, 6], [-13, 6, 4, -1, 3, 6, 0, -6, 5, 0, -6, -2, 1, 6, -3, -6, 6, 0, 10, -1], [7, -12, 5, -8, -1, -2, -6, 8, 2, -2, -6, 0, -11, 1, -3, 4, 4, 9, 2, -3], [0, 8, 2, -2, 0, -4, 2, -10, 6, 4, 2, 6, -3, -6, 1, -1, 4, -8, 2, -3], [0, -9, 2, 3, -2, -5, 0, -1, 9, 5, 0, 4, -2, -8, 4, -1, 3, -2, -11, -2], [6, -11, 6, -10, -5, 0, -10, 0, -1, -4, 1, 9, -8, -3, -1, -1, 5, -17, 8, -4], [21, -16, 3, 0, -6, 0, -4, -8, 11, -4, -5, 2, -9, -1, 4, -2, 1, 2, -2, 8], [6, 2, -8, 2, -4, -2, 11, -3, -3, 4, 4, 5, 10, -8, 8, -9, 1, -5, -6, -2], [-8, 14, 1, -7, -2, 0, -7, 2, -4, -4, 5, 8, 6, 9, -5, -17, 7, -11, 21, -3], [-10, 16, -1, 10, 1, 1, 9, -12, -3, 5, 6, 2, 12, -8, 8, -5, 0, -11, -8, -3], [3, 24, -7, -2, 3, -5, -4, 3, -4, 3, 1, 8, 3, -1, 1, -3, 0, -8, 2, -7], [8, 8, -3, 0, 2, 0, 2, 5, -2, 1, 10, -1, 4, -10, 2, 6, -3, -14, -9, -6], [5, -17, -2, -7, -1, 7, -7, -4, 3, -3, -4, 4, -10, 2, 6, 8, 13, -3, 1, 1], [2, -7, 3, -1, 3, 1, -3, 3, 0, -3, -4, 2, -7, 3, 1, 1, 11, 1, 2, -2], [8, -15, 6, -8, -8, -1, -6, 0, 1, -8, -10, 6, -8, 7, -5, 5, 2, 3, 8, 3], [-7, -8, -8, 11, 7, 3, 14, -2, -3, 11, 2, -7, 0, -10, 9, 23, -11, 7, -23, -8], [-2, -10, 14, 6, 10, 7, -11, -1, 9, 4, -6, -1, -8, 1, -2, -2, 13, 10, 5, 7], [7, 2, 4, 1, 4, -1, 2, -6, 8, 0, -3, 1, 2, -8, 1, 5, 4, -3, -1, -3], [-4, -2, 7, -1, 3, 4, 0, 2, -1, 4, 0, 0, 0, -2, 0, 4, -4, -2, 2, -8], [2, -42, 11, -15, -9, 9, -18, -2, 17, -4, -11, 4, -18, 3, -2, 14, 9, 0, 0, 2], [-6, -12, -2, 1, 2, 0, 2, 9, -1, -5, 4, -1, -7, 2, -4, -3, 4, 8, 6, 5], [-13, 18, -10, 10, -1, -6, 5, -5, -4, 9, 6, 3, 13, -2, 3, -14, -3, 0, -4, 3], [0, -11, 8, -10, 5, -2, -14, 4, 2, -1, -4, 2, -7, 0, -3, 13, 2, -2, 1, -3], [-13, -14, 7, 8, 8, -4, 4, 3, 7, 4, -4, 1, -8, -15, 1, 4, 0, 5, -18, 3], [2, 24, -3, 4, -4, -2, 11, 1, -13, 8, 10, -5, 23, -4, -2, 0, -17, -5, 0, -6], [8, 15, 4, 11, 9, -8, 7, 3, -5, 7, -2, -1, 5, -8, 1, 7, -11, 5, -7, -4], [-14, -11, 10, -5, 3, 4, 3, 5, 3, -5, 0, -4, -4, -2, -6, 1, 8, -6, 2, -3], [15, 22, 3, 11, 7, 0, -2, -6, 4, 7, -2, 2, 8, 0, 2, -5, -2, 9, -1, 4], [3, 28, -11, 13, -6, -10, 6, 4, -17, 6, 3, -5, 12, 11, -4, 0, -29, 24, -4, 8], [2, 13, -7, 11, 4, -1, 10, -1, -10, 8, 7, -9, 17, -7, 5, 12, -16, 1, -15, -6], [11, 21, -10, 10, -5, -9, -10, 9, -17, -3, 5, 2, 6, 16, -5, -15, -16, 11, 9, 7], [6, 25, -8, 4, 4, -1, 15, 0, -8, 7, 13, -3, 18, -5, 4, -6, -2, -14, -1, -7], [-9, -2, 6, 2, 4, 1, 6, 1, 5, 6, 5, -4, 4, 3, 2, 6, -4, 3, 4, -1], [1, -18, 6, -10, -3, 4, 0, 7, 0, -14, 1, 1, -8, -1, -1, 4, 1, 1, 6, -6], [-6, 9, -5, 3, 8, -5, 9, 7, 0, 13, -3, -9, 4, -7, -1, 9, -9, 5, -10, -3], [10, -4, 1, -7, -8, 1, -3, 5, -2, -5, 7, 8, 3, -6, 4, 0, 3, -24, 1, -13], [-3, 7, -11, -4, 4, -1, 6, 7, -15, -2, 5, 2, 7, 7, -2, 5, -7, -3, 6, -9], [4, -26, 8, -4, -6, 3, -12, -7, 8, -2, -6, 9, -14, 4, 0, 0, 10, -5, 1, 2], [6, 6, -2, 1, -4, -6, 6, -3, 3, -3, 3, 3, 3, -3, 0, -8, 4, -10, 0, 3], [11, 8, 5, -8, -6, 2, -4, -13, 4, 1, 9, 13, 3, -9, 12, -4, 8, -21, -3, -8], [1, 4, -8, -4, -4, 1, 5, 6, -2, -3, -2, 0, -6, -3, -1, 10, -17, 8, -10, -6], [-8, -19, 4, 4, 0, -7, -3, 10, 2, 2, -3, -7, -12, 4, -6, 8, -15, 18, -13, 7], [21, 13, -1, -5, -9, -4, -6, -9, -3, -8, 0, 11, 4, -3, 1, -23, 5, -14, 12, 2], [3, 1, 0, 0, 3, 5, 12, -14, 4, 2, -7, 8, -1, -11, 7, 2, 15, -5, -7, -10], [-13, 3, -6, -4, 3, 4, 1, 4, -8, -3, 0, -8, 2, 8, -7, 10, -13, 12, 6, 0], [3, -1, 1, -3, 2, 4, -5, 1, 0, 0, -2, 10, -4, 2, -2, -2, 10, -2, 10, -1], [11, -21, 8, -6, -5, 7, -2, -13, 14, -2, 4, 8, -7, -5, 7, -7, 20, -15, 5, 0], [12, 5, -10, 5, 6, -4, 4, 13, -11, -4, -1, -2, 2, 3, 5, 7, -4, 15, 0, 1], [-2, 8, 8, 10, 4, -3, 0, -5, 4, 7, 0, -2, 4, -6, 1, -3, -1, 10, -6, 6], [8, 12, -9, 4, 0, -4, 6, 10, -23, 1, 8, -4, 11, 7, 2, -7, -11, -3, 4, -8], [-2, -1, 5, -7, 4, -2, -13, -1, 2, -2, 1, -5, 1, 0, -4, -1, 4, -1, 8, -1], [-12, -8, 7, -7, -1, 7, -7, -11, 16, 10, -4, -1, -3, -5, 2, 19, -1, -5, -5, -1], [14, -12, 8, -10, -6, 1, -15, -1, 4, -7, 3, 6, -7, 5, -5, 1, 5, -6, 12, -1], [16, 0, -5, 3, 5, -5, 11, 2, -9, 3, 1, -3, 7, -15, 6, 12, 1, -2, -15, -8], [-5, -3, -8, -4, 1, -6, 4, 13, -3, 3, 10, -4, -6, -5, -1, 9, -15, -2, -15, -2], [-2, -7, 11, 3, -3, -8, -16, -2, 11, 3, -2, 2, -7, -2, -1, -11, 1, 2, -7, 9], [-11, -42, 10, -7, 4, 16, -10, 0, 20, -1, -14, -3, -18, 3, 1, 22, 8, 6, 1, -4], [-4, 8, -1, -5, -19, -2, -10, -4, -4, -2, 7, 2, 4, 8, 3, -9, -14, -9, 3, -3], [-4, 32, -5, 9, 3, -2, 13, -6, -12, 14, 6, -2, 14, -2, 7, -6, -8, -11, -7, -7], [15, -12, -5, 5, -2, 2, 8, 7, -1, -2, -6, -9, 1, 4, -8, 5, -10, 10, -2, 6], [2, 6, -2, 0, -18, -7, -3, 7, -13, -4, 6, -1, 1, 7, -6, 1, -14, 1, 3, 2], [1, 11, -5, -14, -14, 6, -6, 0, -11, -8, 15, 7, 6, 9, -3, -13, 4, -18, 21, -4], [13, 15, -5, -3, -11, -4, -4, 9, -13, -4, 13, 5, -1, 4, 4, -9, -17, -5, 1, -5], [-6, -21, 6, -2, 6, -1, -6, 15, 2, -3, -8, -9, -11, 0, -7, 17, 0, 4, -5, -2], [0, -11, 14, -11, -6, 6, -14, -11, 12, -4, -3, 1, 1, -1, 1, 1, 5, -17, 11, -4], [7, 4, 2, -2, -3, -2, 0, -2, 6, -1, 6, 7, 5, -6, 2, -5, 8, -16, 6, -2], [0, -16, -5, -5, 1, 8, 1, -6, 2, -1, -4, 0, 3, 7, 2, -4, 4, 7, 4, 0], [1, -14, -3, -5, -5, 3, -4, -8, 4, -7, -5, 11, -6, 1, 3, 1, 6, -9, -1, -7], [7, 6, 1, -7, -5, 1, -7, 3, -4, 4, -4, 2, 0, 0, 5, 6, 4, -12, 1, -6], [-9, -3, 8, -4, 8, 10, -9, -6, 21, 3, -7, 7, -11, 0, 1, -4, 17, -12, 5, -3], [-12, 4, 3, -1, 5, 2, 10, 5, 3, 0, -6, -2, 3, -13, -4, 8, 5, -4, -8, -3], [-8, -1, 2, 6, 7, -6, 10, 13, -6, -1, -6, -6, 2, -1, -10, 6, -3, 16, 1, 0], [5, 20, -5, 9, 5, -8, 0, 4, -20, -2, 4, 11, 11, 1, 4, -11, 0, -4, 6, 0], [11, -4, 8, -4, -2, 3, -10, 3, 5, 3, -3, -1, 6, 3, -5, 0, 14, -2, 5, 1], [-12, -16, 6, -7, 3, -5, -12, 7, 10, -5, -13, -9, -15, 1, -10, 4, 4, 8, 4, 9], [-16, -25, 8, -6, -7, -1, -8, 0, 8, 0, -3, 1, 1, 5, -8, 10, 3, -5, 3, 6], [-3, 0, -3, 6, 6, 5, 2, -8, 4, 13, -4, 0, -4, -4, 4, 7, 2, 0, -6, -2], [9, 23, -14, 13, 2, -12, 7, 3, -8, 5, 9, -1, 10, -8, 4, -6, -14, 7, -11, 2], [9, 0, -1, -3, -11, -1, 1, -5, -9, -12, -4, 6, 0, 10, 0, -19, 6, -2, 16, 13], [13, -21, 5, -3, 7, 8, -1, -4, 15, 2, -11, 2, -17, -2, -3, 6, 8, 5, -6, -3], [0, 11, 0, 14, 1, 0, 14, -6, -11, 6, 8, 0, 14, -8, 12, 3, 2, 1, -8, -2], [2, -16, 0, -7, -11, 1, 0, 0, 4, -10, 4, 2, -5, 8, -5, -15, 7, -3, 13, 3], [-2, 2, -5, 2, -3, 0, 11, 10, -7, 8, 1, -5, 5, -4, 9, 17, -9, -5, -16, -6], [3, 10, -6, -5, -9, 8, 4, -12, 2, -4, -6, 2, 0, 5, 5, 3, -2, 1, 2, -7], [-17, -12, -3, -8, 5, -2, 5, 10, -4, -4, -7, -8, -6, 4, -9, 6, 3, 15, 9, 12], [12, -11, -1, 3, -2, 5, 0, -2, -1, -3, -4, -9, 8, 5, 0, 5, -2, 3, -1, 2], [-5, -17, 3, 0, 7, 3, 9, -13, 5, 0, -3, 6, -4, -5, 10, -4, 14, -4, 0, 0], [-20, 11, -11, 2, -3, -8, 6, 5, -10, 4, 5, -6, 9, -4, 6, 4, -20, 5, -11, -5], [5, -11, 3, -9, 1, 5, -8, -10, 12, -4, -10, 7, -11, -3, 3, 7, 6, -6, 3, -8], [3, 12, -9, -6, 0, -7, 6, 4, -7, 0, 8, -4, 12, -4, -4, 0, -14, -8, 2, -7], [-11, -1, 7, 1, 12, 8, 5, -7, 9, 1, -9, 1, -2, 7, -5, -3, 16, -3, 10, 3], [4, -10, 7, -1, 6, -2, -8, 6, 8, 4, 1, 8, -6, -5, -3, 0, 3, 0, -5, 0], [-2, 4, 6, 7, 4, -2, 6, -6, 3, 10, 5, 1, 3, -13, 0, 6, -6, 3, -15, -6], [-9, 30, -10, 9, 2, -13, 11, 0, -18, 11, 13, -7, 16, -6, 7, 4, -24, -2, -11, -10], [22, 11, -2, -5, -10, -9, -6, -4, -6, 4, 12, 7, 9, -8, 10, -2, -3, -28, -5, -8], [-17, 5, -2, -5, -9, -3, -8, 1, -5, -3, 6, 0, 10, 12, -4, -7, 0, -14, 16, 4], [33, 12, 1, -1, -16, -1, -8, -10, -4, -1, 6, 8, 15, 9, 1, -14, 3, -20, 11, 1], [-7, 1, 0, 9, 1, 1, -4, -2, -6, -3, 4, 5, -2, 4, 8, -7, 1, 11, 0, 4], [-10, 16, -9, 16, 6, -1, 25, -2, -13, 3, 3, -3, 15, -7, 1, -4, -8, 8, -14, -1], [-1, -9, -9, -1, -5, -2, 11, 6, -3, -8, 1, -2, 4, 1, -2, 8, -10, 6, -6, -3], [-11, 5, 8, 4, 4, -8, -7, -9, 9, 10, -3, 10, 1, -5, 1, -14, 8, -5, -5, 7], [-23, 14, -8, 7, -3, 3, 4, -9, 0, 0, 3, 0, 9, 10, 4, -4, -9, 5, 2, 5], [-4, -3, -4, 4, 11, 0, 13, 12, -3, 6, -6, -13, -1, -13, 2, 29, -9, 5, -17, -10], [13, -8, 4, 2, 3, 2, 1, 0, 4, -3, 1, -5, -8, -3, 2, 2, 10, 4, -6, 2], [-2, 0, 3, -4, 1, 0, 4, 5, 2, 5, 4, -1, -4, -11, 3, 17, -7, -5, -12, -1], [-13, -2, 7, -6, 4, 8, 2, -6, 5, 1, 2, 15, 5, -15, 4, -3, 14, -23, 10, -13], [3, -26, 7, -7, -3, 12, -11, -1, 17, -11, -6, 8, -21, 9, -3, 2, 15, -6, 11, 2], [-11, -1, 1, 11, 1, 5, 8, -4, -10, 6, 11, -4, 13, 3, 4, -4, -5, -7, -5, -1], [-6, -22, 5, -7, -13, 12, -5, -15, 17, -16, -12, 2, -21, 11, 1, -5, 14, 4, 10, 15], [20, 21, -14, 3, -10, -4, 11, 0, -13, 6, 20, -8, 10, 3, 4, -5, -25, -10, -12, -5], [-18, -8, -6, 1, -10, 4, 13, 0, -7, -6, -4, -2, 6, 0, 5, 1, -4, -5, -5, -2], [2, -12, 2, -6, 8, 1, -8, -4, 17, -2, -3, 3, -4, -4, -4, 0, 15, -12, 5, -1], [7, 6, -1, 1, -1, 4, 2, 9, -9, -3, 4, -2, 4, 10, -4, 7, -3, 3, 8, -1], [-11, 0, 1, -2, 7, -3, 1, 8, 1, -3, -13, 0, -11, 0, -11, 5, 9, 21, 2, 12], [0, -10, 3, -1, 6, 9, -8, -4, 6, -3, -1, -1, -9, 0, -4, -5, 9, -2, 1, 2], [-5, 12, -2, 0, 11, -7, 0, 12, -7, -1, -4, -1, -4, 5, -7, 4, 2, 19, 5, 6], [-18, -30, 6, -2, 1, 6, -9, 7, 10, -7, -6, -4, -15, 15, -8, 1, 16, 3, 14, 11], [-4, -5, -2, 2, 9, -1, 2, -4, -3, 3, 0, 4, -2, -2, 1, 9, 0, 11, -1, -9], [2, -16, -4, -11, -6, 7, -17, -5, 13, -8, -11, 3, -11, 12, -12, -15, 19, 8, 12, 16], [26, 10, -13, 0, -18, 3, 7, -3, -6, -7, -4, 8, -4, 14, 0, -17, 1, 5, 1, 11], [-4, 6, -1, 0, 2, 0, -6, -1, 0, 6, 8, 3, -7, -6, 3, 2, 2, -7, -9, -1], [-29, 8, 4, 11, 5, 7, -6, -10, 7, 3, -13, 7, 2, 8, -3, -8, 13, -4, 11, 6], [-6, -2, -3, 2, 1, -11, 10, 15, -19, -3, 3, -13, 4, 0, -6, 3, -12, 7, -2, 8], [-13, 23, -9, 14, 1, -6, 14, -1, -18, -4, 0, 8, 8, 6, 4, -13, 3, 7, 9, 5], [-12, -3, 1, -6, 3, 11, 8, -10, 2, 5, 6, 1, 7, -12, 12, 6, 16, -20, 5, -13], [6, -5, -7, 10, 6, 5, -3, 7, -8, -4, -1, 5, -12, 9, 8, -6, 3, 16, 2, 2], [-6, 21, -18, 19, 12, -9, 20, 4, -15, 9, 1, -12, 11, 0, 5, 5, -19, 26, -15, 1], [-18, -9, 2, 5, 15, 1, 3, 15, -2, 9, -4, -12, -6, -7, 2, 14, -4, 6, -13, -6], [14, -21, 5, -10, 9, -1, -6, -6, 8, 4, -2, -2, -2, -9, 9, 7, 12, -7, -5, -7], [-2, -12, -1, 1, -7, -2, -8, 1, 5, -8, -1, -3, -14, 3, -2, 3, -6, 9, -2, 11], [16, 9, -1, 4, -13, 0, -1, -5, -8, -8, -7, 3, 0, 15, 2, -14, 8, 9, 4, 13], [12, 8, -4, 8, -6, -15, 0, 2, -11, 3, 5, -4, -3, 1, 3, -1, -23, 8, -15, 6], [18, 24, -10, 6, -11, -3, 9, 1, -14, 3, 15, 0, 24, 6, 6, -10, -7, -3, 5, -2], [-6, -9, 0, 0, -5, 4, 0, -9, 2, -2, -1, -5, -7, 7, 3, 0, -6, 8, -2, 4], [11, -9, 1, 3, -4, 6, 2, 2, -2, 8, 2, -4, 2, 8, 5, 16, -11, 0, -5, -7], [-19, 7, 1, -3, -9, 5, -6, -11, 9, -1, -1, 6, -5, 13, -7, -7, 1, 1, 9, 2], [-8, -8, 5, 13, 20, 4, 15, 5, 0, 9, -4, -13, 5, -10, 3, 14, -3, 13, -10, -12], [-19, -3, 3, -2, 1, -1, 3, 1, 0, -1, 7, -12, -3, -3, -4, -3, 6, -2, 4, 7], [7, -26, 3, 0, -3, 6, -6, -11, 5, -1, -2, 9, -5, 3, 8, -1, 10, -2, -1, 5], [-26, 9, -3, 7, 5, -5, 3, 8, 1, 1, -2, -9, -5, -1, -9, 5, -10, 14, -5, 4], [-3, -4, -1, -5, -5, -1, 3, 5, -3, -3, -7, 1, -8, 0, -4, 1, -12, 1, -3, -1], [6, -14, 2, -6, 11, 0, 3, 2, 7, -2, -6, 8, -16, -5, 1, 10, -2, 14, -10, -6], [-11, -7, 2, 5, 6, 0, 8, 7, -4, -5, -1, 0, -2, 4, -4, 0, 3, 11, 10, 6], [14, 0, -3, 6, 2, -9, -2, 20, -14, -2, -5, -13, 0, 6, -14, 9, -20, 29, -7, 13], [2, 0, -10, -11, -2, 4, 12, 0, -4, 2, 10, -1, 2, -8, 12, 6, 4, -8, -6, -6], [7, -1, 1, 4, 3, -4, -2, -11, 3, 3, 1, 9, -1, -8, 9, 6, 0, 1, -6, -8], [16, 40, -9, 21, -4, -11, 7, -5, -22, 14, 10, 6, 22, -1, 9, -15, -9, -2, -4, 2], [1, 16, -9, 13, -11, -3, -5, -7, 0, 2, -2, 1, 6, 11, -4, -19, -7, 6, 3, 14], [-2, -27, 2, -5, 6, -1, -3, 8, 16, 0, -16, -4, -19, -3, -7, 18, -3, 11, -11, -2], [17, 20, -5, 0, -5, 4, -2, -6, -8, -5, 12, 6, 8, 4, -3, -16, 1, -3, 12, -8], [-23, -37, 14, -7, 16, 9, -10, -4, 24, -6, -17, 6, -14, -3, -4, 0, 30, 2, 11, 11], [19, 21, -5, 5, -17, -10, -3, -11, -13, 0, 21, 8, 12, -2, 7, -13, -2, -12, 6, 0], [-13, -2, -8, 4, 2, -4, -5, 3, 4, 3, -9, -7, -5, 5, 0, 3, -6, 23, -1, 5], [-8, 5, 3, -2, -7, 0, -8, -6, 10, 11, 5, 1, 1, 5, -3, -6, 4, -4, -2, 5], [5, -27, 11, -3, -4, 18, -10, -14, 21, 0, -9, 2, -10, 0, 6, 0, 24, -13, 7, 8], [-5, 3, -2, -8, 7, 0, 2, 0, 2, -3, -2, 5, -9, -10, 4, 0, 8, -4, -6, -9], [-15, -22, 17, -7, -9, 11, -33, -12, 20, -10, -9, 10, -10, 17, -3, -16, 26, -13, 29, 6], [4, 8, -1, 8, 0, -2, 4, -7, 1, 10, 3, 0, 10, -13, 9, 2, -4, 3, -12, -8], [-2, 13, -1, 10, -1, 0, 4, -5, -8, -4, 1, 10, 1, 2, 7, -9, -3, 4, 4, 5], [19, 0, 7, 3, -3, 2, -4, -10, 6, -10, -6, 4, -4, 10, 4, -15, 13, 5, 11, 5], [13, 14, 7, -1, 6, -5, -4, -3, 0, 16, 5, -13, 9, -3, -3, 13, -8, -17, -9, -9], [-9, -18, 8, -4, 18, 9, 4, 5, 6, -2, -8, -4, -12, -4, 0, 11, 8, 7, -2, -7], [8, 14, 0, -1, -10, -9, -13, -1, 0, 0, 4, 4, 2, -4, 0, -20, -4, -8, -4, 11], [15, -16, 9, -14, -2, 6, -2, -6, 13, -9, 10, 5, -7, -2, 2, -9, 10, -15, 6, -11], [-5, -12, 2, 4, 6, 7, 19, -3, 5, 12, 8, -10, 1, -18, 8, 16, 1, -10, -20, -10], [-36, 17, 6, 8, 4, -6, 4, 8, -8, 4, 8, -7, 5, -7, -6, -2, -8, 0, -6, -1], [-8, 12, 6, 10, 8, -1, 6, -4, 4, 11, 9, -2, 4, -15, 3, 1, -1, -9, -9, -10]]
